Truecolor
=========

A True color terminal library for Python — similar in function to the
`termcolor library <https://pypi.python.org/pypi/termcolor/1.1.0>`__. It
allows one to output color text in supported terminals using escape
codes.

Available functions
-------------------

-  **bold** - Return a bolder version of a color tuple.
-  **dim** - Return a dimmer version of a color tuple.
-  **hex\_to\_rgb** - Return a tuple of (red, green, blue) for a color
   given as #rrggbb.
-  **rgb\_to\_hex** - Return color as #rrggbb for the given color tuple
   or component values.
-  **fore\_text** - Return text string with foreground only set.
-  **color\_text** - Return text string with foreground and background
   set.
-  **fore\_print** - Print text string with foreground only set.
-  **color\_print** - Print text string with foreground and background
   set.
